Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RecombineOperator ¶
type RecombineOperator struct {
helper.TransformerOperator
sync.Mutex
// contains filtered or unexported fields
}
RecombineOperator is an operator that combines a field from consecutive log entries into a single
func (*RecombineOperator) Start ¶
func (r *RecombineOperator) Start() error
Start will start the processing log entries
func (*RecombineOperator) Stop ¶
func (r *RecombineOperator) Stop() error
Stop will stop processing log entries
type RecombineOperatorConfig ¶
type RecombineOperatorConfig struct {
helper.TransformerConfig `yaml:",inline"`
IsFirstEntry string `json:"is_first_entry" yaml:"is_first_entry"`
IsLastEntry string `json:"is_last_entry" yaml:"is_last_entry"`
MaxBatchSize int `json:"max_batch_size" yaml:"max_batch_size"`
CombineField entry.Field `json:"combine_field" yaml:"combine_field"`
OverwriteWith string `json:"overwrite_with" yaml:"overwrite_with"`
}
RecombineOperatorConfig is the configuration of a recombine operator
func NewRecombineOperatorConfig ¶
func NewRecombineOperatorConfig(operatorID string) *RecombineOperatorConfig
NewRecombineOperatorConfig creates a new recombine config with default values
func (*RecombineOperatorConfig) Build ¶
func (c *RecombineOperatorConfig) Build(bc operator.BuildContext) ([]operator.Operator, error)
Build creates a new RecombineOperator from a config
Click to show internal directories.
Click to hide internal directories.